@@ -136,7 +136,7 @@ def getPythonFiles(parent: str = None) -> list:
         list: a list of str objects representing a path to a .py file
     """
     # major folders to exclude
-    exclude = ['.git', '.vscode', 'env', 'Lib', 'site-packages', 'build', 'dist']
+    exclude = ['.git', '.vscode', 'env', 'Lib', 'site-packages', 'build', 'dist', 'output']
     parent = os.getcwd() if parent is None else parent
 
     retList = []
@@ -163,6 +163,7 @@ def GenDoc(args) -> None:
         for i, file in enumerate(args.files):
             args.files[i] = rf"{args.files[i]}"
             if not file.endswith('.py') or not os.path.exists(file):
+                print(f"Excluding {file} because it is not a valid file.")
                 del args.files[i]
                 i -= 1
 
@@ -173,6 +174,7 @@ def GenDoc(args) -> None:
     # Starting markdown header
     markdown = f"``{args.name}``" if args.name else ""
     markdown += f" **{args.version}**" if (args.name and args.version) else markdown
+    markdown += "\n" if (args.name or args.version) else ""
 
     # Validating output file if supplied
     if args.output and not args.output.endswith('.md'):
